/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.unibi.techfak.scie.classifiers.annotators;

import de.unibi.techfak.scie.descriptors.Annotation;
import de.unibi.techfak.scie.classifiers.data.ClassificationResult;
import java.util.Objects;

/**
 * This is a model for a slot candidate of a relation.
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 * @param <S> the slot annotation class.
 */
public class SlotCandidate<S extends Annotation> {

	private final S annotation;
	private final ClassificationResult result;

	public SlotCandidate(S annotation, ClassificationResult result) {
		this.annotation = annotation;
		this.result = result;
	}

	public S getAnnotation() {
		return annotation;
	}

	public ClassificationResult getResult() {
		return result;
	}

	@Override
	public int hashCode() {
		int hash = 7;
		hash = 79 * hash + Objects.hashCode(this.annotation);
		hash = 79 * hash + Objects.hashCode(this.result);
		return hash;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		final SlotCandidate<?> other = (SlotCandidate<?>) obj;
		if (!Objects.equals(this.annotation, other.annotation)) {
			return false;
		}
		if (!Objects.equals(this.result, other.result)) {
			return false;
		}
		return true;
	}
}
