/*
 * SCIE -- Spinal Cord Injury Ontology Extraction
 * Copyright (C) 2013, 2014
 * Raphael Dickfelder, Jan Göpfert, Benjamin Paaßen, Andreas Stöckel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.techfak.scie.classifiers;

import de.unibi.techfak.scie.descriptors.Token;
import java.util.ArrayList;
import junit.framework.TestCase;
import org.apache.uima.UIMAException;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.jcas.JCas;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class NonOverlappingCacheTest extends TestCase {
	
	public static final String TYPESYSTEM = 
		"src/main/resources/de/unibi/techfak/scie/descriptors/SCIEClassifiers";

	public NonOverlappingCacheTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * Test of getInstance method, of class NonOverlappingCache.
	 */
	public void testGetInstance() throws UIMAException {
		final JCas jcas = JCasFactory.createJCas(TYPESYSTEM);
		final NonOverlappingCache instance = NonOverlappingCache.getInstance(jcas);
		assertNotNull(instance);
		assertSame(instance, NonOverlappingCache.getInstance(jcas));
		for (int i = 0; i < NonOverlappingCache.MAX_NUM_INSTANCES; i++) {
			final JCas otherJCas = JCasFactory.createJCas(TYPESYSTEM);
			final NonOverlappingCache otherInstance
					= NonOverlappingCache.getInstance(otherJCas);
			assertNotSame(instance, otherInstance);
		}
		assertNotSame(instance, NonOverlappingCache.getInstance(jcas));
	}

	/**
	 * Test of selectBetween method, of class NonOverlappingCache.
	 */
	public void testSelectBetween() throws UIMAException {
		final JCas jcas = JCasFactory.createJCas(TYPESYSTEM);
		jcas.setDocumentText("Test tokens.");
		final Token token1 = new Token(jcas, 0, 3);
		token1.addToIndexes();
		final Token token2 = new Token(jcas, 5, 10);
		token2.addToIndexes();
		final NonOverlappingCache instance = NonOverlappingCache.getInstance(jcas);
		ArrayList<Token> selectBetween = instance.selectBetween(Token.class, 0, 3);
		assertEquals(1, selectBetween.size());
		assertSame(token1, selectBetween.get(0));
		selectBetween = instance.selectBetween(Token.class, 5, 10);
		assertEquals(1, selectBetween.size());
		assertSame(token2, selectBetween.get(0));
		selectBetween = instance.selectBetween(Token.class, 1, 8);
		assertEquals(2, selectBetween.size());
		assertSame(token1, selectBetween.get(0));
		assertSame(token2, selectBetween.get(1));
	}

}
